plot_rwa: Plot the rescaled importance values from the output of...

View source: R/plot_rwa.R

plot_rwaR Documentation

Plot the rescaled importance values from the output of rwa()

Description

Pass the output of rwa() and plot a bar chart of the rescaled importance values. Signs are always calculated and taken into account, which is equivalent to setting the applysigns argument to TRUE in rwa().

Usage

plot_rwa(rwa)

Arguments

rwa

Direct list output from rwa().

Examples


library(ggplot2)
# Use a smaller sample for faster execution
diamonds_small <- diamonds[sample(nrow(diamonds), 1000), ]
diamonds_small %>%
  rwa(outcome = "price",
      predictors = c("depth","carat", "x", "y", "z"),
      applysigns = TRUE) %>%
  plot_rwa()



rwa documentation built on Jan. 21, 2026, 1:07 a.m.