remove_all_na_cols: Remove any columns where all the values are missing

View source: R/remove_all_na_cols.R

remove_all_na_colsR Documentation

Remove any columns where all the values are missing

Description

Pass a data frame and returns a version where all columns made up of entirely missing values are removed.

Usage

remove_all_na_cols(df)

Arguments

df

Data frame to be passed through.

Details

This is used within rwa().


rwa documentation built on Jan. 21, 2026, 1:07 a.m.