| plot_rwa | R Documentation |
rwa()Pass the output of rwa() and plot a bar chart of the rescaled importance values.
Signs are always calculated and taken into account, which is equivalent to setting the applysigns
argument to TRUE in rwa().
plot_rwa(rwa)
rwa |
Direct list output from |
library(ggplot2)
# Use a smaller sample for faster execution
diamonds_small <- diamonds[sample(nrow(diamonds), 1000), ]
diamonds_small %>%
rwa(outcome = "price",
predictors = c("depth","carat", "x", "y", "z"),
applysigns = TRUE) %>%
plot_rwa()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.